@@ -91,8 +91,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_RES
             wrapper->UAV->decoded_value = &(value->UAV);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->UAV);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -121,8 +119,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_TEX
             wrapper->PlacedFootprint->decoded_value = &(value->PlacedFootprint);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->PlacedFootprint);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -200,8 +196,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_SHA
             bytes_read += DecodeStruct(
                 (buffer + bytes_read), (buffer_size - bytes_read), wrapper->RaytracingAccelerationStructure);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -250,8 +244,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_UNO
             wrapper->Texture3D->decoded_value = &(value->Texture3D);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Texture3D);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -310,8 +302,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_REN
             wrapper->Texture3D->decoded_value = &(value->Texture3D);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Texture3D);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -361,8 +351,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_DEP
             wrapper->Texture2DMSArray->decoded_value = &(value->Texture2DMSArray);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Texture2DMSArray);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -397,8 +385,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_ROO
             wrapper->Descriptor->decoded_value = &(value->Descriptor);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Descriptor);
             break;
-        default:
-            break;
     }
 
     bytes_read +=
@@ -436,8 +422,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_ROO
             wrapper->Descriptor->decoded_value = &(value->Descriptor);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Descriptor);
             break;
-        default:
-            break;
     }
 
     bytes_read +=
@@ -467,8 +451,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_VER
             wrapper->Desc_1_1->decoded_value = &(value->Desc_1_1);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Desc_1_1);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -514,8 +496,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_RAY
             wrapper->AABBs->decoded_value = &(value->AABBs);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->AABBs);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -558,12 +538,8 @@ size_t DecodeStruct(const uint8_t*
                     bytes_read += wrapper->ppGeometryDescs->Decode((buffer + bytes_read), (buffer_size - bytes_read));
                     value->ppGeometryDescs = wrapper->ppGeometryDescs->GetPointer();
                     break;
-                default:
-                    break;
             }
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -596,8 +572,6 @@ DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_VERSIONED_
             wrapper->Dred_1_2->decoded_value = &(value->Dred_1_2);
             bytes_read += DecodeStruct((buffer + bytes_read), (buffer_size - bytes_read), wrapper->Dred_1_2);
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -996,9 +970,9 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_STA
     bytes_read +=
         ValueDecoder::DecodeSizeTValue((buffer + bytes_read), (buffer_size - bytes_read), &(wrapper->subobject_stride));
 
-    wrapper->subobjects = DecodeAllocator::Allocate<StructPointerDecoder<Decoded_D3D12_STATE_SUBOBJECT>>();
-    bytes_read += wrapper->subobjects->Decode((buffer + bytes_read), (buffer_size - bytes_read));
-    value->pSubobjects = wrapper->subobjects->GetPointer();
+    wrapper->pSubobjects = DecodeAllocator::Allocate<StructPointerDecoder<Decoded_D3D12_STATE_SUBOBJECT>>();
+    bytes_read += wrapper->pSubobjects->Decode((buffer + bytes_read), (buffer_size - bytes_read));
+    value->pSubobjects = wrapper->pSubobjects->GetPointer();
 
     return bytes_read;
 }
@@ -1088,8 +1062,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_STA
             break;
         case D3D12_STATE_SUBOBJECT_TYPE_MAX_VALID:
             break;
-        default:
-            break;
     }
 
     return bytes_read;
@@ -1142,8 +1114,6 @@ size_t DecodeStruct(const uint8_t* buffer, size_t buffer_size, Decoded_D3D12_BAR
             bytes_read += wrapper->buffer_barriers->Decode((buffer + bytes_read), (buffer_size - bytes_read));
             value->pBufferBarriers = wrapper->buffer_barriers->GetPointer();
             break;
-        default:
-            break;
     }
 
     return bytes_read;
