@@ -39,7 +39,7 @@
 GFXRECON_BEGIN_NAMESPACE(gfxrecon)
 GFXRECON_BEGIN_NAMESPACE(decode)
 
-class VulkanStatsConsumer : public gfxrecon::decode::VulkanConsumer, public gfxrecon::decode::AnnotationHandler
+class VulkanStatsConsumer : public gfxrecon::decode::VulkanConsumer
 {
   public:
     uint32_t                        GetTrimmedStartFrame() const { return trimmed_frame_; }
@@ -55,8 +55,6 @@ class VulkanStatsConsumer : public gfxrecon::decode::VulkanConsumer, public gfxr
     uint64_t                        GetAllocationCount() const { return allocation_count_; }
     uint64_t                        GetMinAllocationSize() const { return min_allocation_size_; }
     uint64_t                        GetMaxAllocationSize() const { return max_allocation_size_; }
-    uint64_t                        GetAnnotationCount() const { return annotation_count_; }
-    const std::vector<std::string>& GetOperationAnnotationDatas() const { return operation_annotation_datas_; }
 
     const std::set<gfxrecon::format::HandleId>& GetInstantiatedDevices() const { return used_physical_devices_; }
     const VkPhysicalDeviceProperties*           GetDeviceProperties(gfxrecon::format::HandleId id) const
@@ -76,21 +74,6 @@ class VulkanStatsConsumer : public gfxrecon::decode::VulkanConsumer, public gfxr
         trimmed_frame_ = static_cast<uint32_t>(frame_number);
     }
 
-    /// @brief Count all annotations and save the operation ones which contain data
-    /// such as build versions from the tools that have processed the file.
-    virtual void ProcessAnnotation(uint64_t                         block_index,
-                                   gfxrecon::format::AnnotationType type,
-                                   const std::string&               label,
-                                   const std::string&               data) override
-    {
-        ++annotation_count_;
-        if (type == gfxrecon::format::AnnotationType::kJson &&
-            label.compare(gfxrecon::format::kAnnotationLabelOperation) == 0)
-        {
-            operation_annotation_datas_.push_back(data);
-        }
-    }
-
     virtual void Process_vkCreateInstance(
         const gfxrecon::decode::ApiCallInfo&                                                    call_info,
         VkResult                                                                                returnValue,
@@ -434,10 +417,6 @@ class VulkanStatsConsumer : public gfxrecon::decode::VulkanConsumer, public gfxr
     uint64_t allocation_count_{ 0 };
     uint64_t min_allocation_size_{ std::numeric_limits<uint64_t>::max() };
     uint64_t max_allocation_size_{ 0 };
-
-    // Annotation info.
-    std::vector<std::string> operation_annotation_datas_;
-    uint64_t                 annotation_count_{ 0 };
 };
 
 GFXRECON_END_NAMESPACE(decode)
