@@ -82,6 +82,8 @@ GFXRECON_BEGIN_NAMESPACE(encode)
 #define SCREENSHOT_FRAMES_UPPER                              "SCREENSHOT_FRAMES"
 #define CAPTURE_FRAMES_LOWER                                 "capture_frames"
 #define CAPTURE_FRAMES_UPPER                                 "CAPTURE_FRAMES"
+#define QUIT_AFTER_CAPTURE_FRAMES_LOWER                      "quit_after_capture_frames"
+#define QUIT_AFTER_CAPTURE_FRAMES_UPPER                      "QUIT_AFTER_CAPTURE_FRAMES"
 #define CAPTURE_TRIGGER_LOWER                                "capture_trigger"
 #define CAPTURE_TRIGGER_UPPER                                "CAPTURE_TRIGGER"
 #define CAPTURE_TRIGGER_FRAMES_LOWER                         "capture_trigger_frames"
@@ -90,6 +92,8 @@ GFXRECON_BEGIN_NAMESPACE(encode)
 #define CAPTURE_ANDROID_TRIGGER_UPPER                        "CAPTURE_ANDROID_TRIGGER"
 #define CAPTURE_IUNKNOWN_WRAPPING_LOWER                      "capture_iunknown_wrapping"
 #define CAPTURE_IUNKNOWN_WRAPPING_UPPER                      "CAPTURE_IUNKNOWN_WRAPPING"
+#define CAPTURE_QUEUE_SUBMITS_LOWER                          "capture_queue_submits"
+#define CAPTURE_QUEUE_SUBMITS_UPPER                          "CAPTURE_QUEUE_SUBMITS"
 #define PAGE_GUARD_COPY_ON_MAP_LOWER                         "page_guard_copy_on_map"
 #define PAGE_GUARD_COPY_ON_MAP_UPPER                         "PAGE_GUARD_COPY_ON_MAP"
 #define PAGE_GUARD_SEPARATE_READ_LOWER                       "page_guard_separate_read"
@@ -120,6 +124,8 @@ GFXRECON_BEGIN_NAMESPACE(encode)
 #define FORCE_COMMAND_SERIALIZATION_UPPER                    "FORCE_COMMAND_SERIALIZATION"
 #define QUEUE_ZERO_ONLY_LOWER                                "queue_zero_only"
 #define QUEUE_ZERO_ONLY_UPPER                                "QUEUE_ZERO_ONLY"
+#define ALLOW_PIPELINE_COMPILE_REQUIRED_LOWER                "allow_pipeline_compile_required"
+#define ALLOW_PIPELINE_COMPILE_REQUIRED_UPPER                "ALLOW_PIPELINE_COMPILE_REQUIRED"
 #define RV_ANNOTATION_EXPERIMENTAL_LOWER                     "rv_annotation_experimental"
 #define RV_ANNOTATION_EXPERIMENTAL_UPPER                     "RV_ANNOTATION_EXPERIMENTAL"
 #define RV_ANNOTATION_RAND_LOWER                             "rv_annotation_rand"
@@ -155,9 +161,11 @@ const char kScreenshotDirEnvVar[]                            = GFXRECON_ENV_VAR_
 const char kScreenshotFormatEnvVar[]                         = GFXRECON_ENV_VAR_PREFIX SCREENSHOT_FORMAT_LOWER;
 const char kScreenshotFramesEnvVar[]                         = GFXRECON_ENV_VAR_PREFIX SCREENSHOT_FRAMES_LOWER;
 const char kCaptureFramesEnvVar[]                            = GFXRECON_ENV_VAR_PREFIX CAPTURE_FRAMES_LOWER;
+const char kQuitAfterFramesEnvVar[]                          = GFXRECON_ENV_VAR_PREFIX QUIT_AFTER_CAPTURE_FRAMES_LOWER;
 const char kCaptureTriggerEnvVar[]                           = GFXRECON_ENV_VAR_PREFIX CAPTURE_TRIGGER_LOWER;
 const char kCaptureTriggerFramesEnvVar[]                     = GFXRECON_ENV_VAR_PREFIX CAPTURE_TRIGGER_FRAMES_LOWER;
 const char kCaptureIUnknownWrappingEnvVar[]                  = GFXRECON_ENV_VAR_PREFIX CAPTURE_IUNKNOWN_WRAPPING_LOWER;
+const char kCaptureQueueSubmitsEnvVar[]                      = GFXRECON_ENV_VAR_PREFIX CAPTURE_QUEUE_SUBMITS_LOWER;
 const char kPageGuardCopyOnMapEnvVar[]                       = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_COPY_ON_MAP_LOWER;
 const char kPageGuardSeparateReadEnvVar[]                    = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_SEPARATE_READ_LOWER;
 const char kPageGuardPersistentMemoryEnvVar[]                = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_PERSISTENT_MEMORY_LOWER;
@@ -174,6 +182,7 @@ const char kDisableDxrEnvVar[]                               = GFXRECON_ENV_VAR_
 const char kAccelStructPaddingEnvVar[]                       = GFXRECON_ENV_VAR_PREFIX ACCEL_STRUCT_PADDING_LOWER;
 const char kForceCommandSerializationEnvVar[]                = GFXRECON_ENV_VAR_PREFIX FORCE_COMMAND_SERIALIZATION_LOWER;
 const char kQueueZeroOnlyEnvVar[]                            = GFXRECON_ENV_VAR_PREFIX QUEUE_ZERO_ONLY_LOWER;
+const char kAllowPipelineCompileRequiredEnvVar[]             = GFXRECON_ENV_VAR_PREFIX ALLOW_PIPELINE_COMPILE_REQUIRED_LOWER;
 const char kAnnotationExperimentalEnvVar[]                   = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_EXPERIMENTAL_LOWER;
 const char kAnnotationRandEnvVar[]                           = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_RAND_LOWER;
 const char kAnnotationGPUVAEnvVar[]                          = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_GPUVA_LOWER;
@@ -205,6 +214,7 @@ const char kScreenshotDirEnvVar[]                            = GFXRECON_ENV_VAR_
 const char kScreenshotFormatEnvVar[]                         = GFXRECON_ENV_VAR_PREFIX SCREENSHOT_FORMAT_UPPER;
 const char kScreenshotFramesEnvVar[]                         = GFXRECON_ENV_VAR_PREFIX SCREENSHOT_FRAMES_UPPER;
 const char kCaptureFramesEnvVar[]                            = GFXRECON_ENV_VAR_PREFIX CAPTURE_FRAMES_UPPER;
+const char kQuitAfterFramesEnvVar[]                          = GFXRECON_ENV_VAR_PREFIX QUIT_AFTER_CAPTURE_FRAMES_UPPER;
 const char kPageGuardCopyOnMapEnvVar[]                       = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_COPY_ON_MAP_UPPER;
 const char kPageGuardSeparateReadEnvVar[]                    = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_SEPARATE_READ_UPPER;
 const char kPageGuardPersistentMemoryEnvVar[]                = GFXRECON_ENV_VAR_PREFIX PAGE_GUARD_PERSISTENT_MEMORY_UPPER;
@@ -217,12 +227,14 @@ const char kPageGuardSignalHandlerWatcherMaxRestoresEnvVar[] = GFXRECON_ENV_VAR_
 const char kCaptureTriggerEnvVar[]                           = GFXRECON_ENV_VAR_PREFIX CAPTURE_TRIGGER_UPPER;
 const char kCaptureTriggerFramesEnvVar[]                     = GFXRECON_ENV_VAR_PREFIX CAPTURE_TRIGGER_FRAMES_UPPER;
 const char kCaptureIUnknownWrappingEnvVar[]                  = GFXRECON_ENV_VAR_PREFIX CAPTURE_IUNKNOWN_WRAPPING_UPPER;
+const char kCaptureQueueSubmitsEnvVar[]                      = GFXRECON_ENV_VAR_PREFIX CAPTURE_QUEUE_SUBMITS_UPPER;
 const char kDebugLayerEnvVar[]                               = GFXRECON_ENV_VAR_PREFIX DEBUG_LAYER_UPPER;
 const char kDebugDeviceLostEnvVar[]                          = GFXRECON_ENV_VAR_PREFIX DEBUG_DEVICE_LOST_UPPER;
 const char kDisableDxrEnvVar[]                               = GFXRECON_ENV_VAR_PREFIX DISABLE_DXR_UPPER;
 const char kAccelStructPaddingEnvVar[]                       = GFXRECON_ENV_VAR_PREFIX ACCEL_STRUCT_PADDING_UPPER;
 const char kForceCommandSerializationEnvVar[]                = GFXRECON_ENV_VAR_PREFIX FORCE_COMMAND_SERIALIZATION_UPPER;
 const char kQueueZeroOnlyEnvVar[]                            = GFXRECON_ENV_VAR_PREFIX QUEUE_ZERO_ONLY_UPPER;
+const char kAllowPipelineCompileRequiredEnvVar[]             = GFXRECON_ENV_VAR_PREFIX ALLOW_PIPELINE_COMPILE_REQUIRED_UPPER;
 const char kAnnotationExperimentalEnvVar[]                   = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_EXPERIMENTAL_UPPER;
 const char kAnnotationRandEnvVar[]                           = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_RAND_UPPER;
 const char kAnnotationGPUVAEnvVar[]                          = GFXRECON_ENV_VAR_PREFIX RV_ANNOTATION_GPUVA_UPPER;
@@ -253,9 +265,11 @@ const std::string kOptionKeyScreenshotDir                            = std::stri
 const std::string kOptionKeyScreenshotFormat                         = std::string(kSettingsFilter) + std::string(SCREENSHOT_FORMAT_LOWER);
 const std::string kOptionKeyScreenshotFrames                         = std::string(kSettingsFilter) + std::string(SCREENSHOT_FRAMES_LOWER);
 const std::string kOptionKeyCaptureFrames                            = std::string(kSettingsFilter) + std::string(CAPTURE_FRAMES_LOWER);
+const std::string kOptionKeyQuitAfterCaptureFrames                   = std::string(kSettingsFilter) + std::string(QUIT_AFTER_CAPTURE_FRAMES_LOWER);
 const std::string kOptionKeyCaptureTrigger                           = std::string(kSettingsFilter) + std::string(CAPTURE_TRIGGER_LOWER);
 const std::string kOptionKeyCaptureTriggerFrames                     = std::string(kSettingsFilter) + std::string(CAPTURE_TRIGGER_FRAMES_LOWER);
 const std::string kOptionKeyCaptureIUnknownWrapping                  = std::string(kSettingsFilter) + std::string(CAPTURE_IUNKNOWN_WRAPPING_LOWER);
+const std::string kOptionKeyCaptureQueueSubmits                      = std::string(kSettingsFilter) + std::string(CAPTURE_QUEUE_SUBMITS_LOWER);
 const std::string kOptionKeyPageGuardCopyOnMap                       = std::string(kSettingsFilter) + std::string(PAGE_GUARD_COPY_ON_MAP_LOWER);
 const std::string kOptionKeyPageGuardSeparateRead                    = std::string(kSettingsFilter) + std::string(PAGE_GUARD_SEPARATE_READ_LOWER);
 const std::string kOptionKeyPageGuardPersistentMemory                = std::string(kSettingsFilter) + std::string(PAGE_GUARD_PERSISTENT_MEMORY_LOWER);
@@ -271,6 +285,7 @@ const std::string kOptionDisableDxr                                  = std::stri
 const std::string kOptionAccelStructPadding                          = std::string(kSettingsFilter) + std::string(ACCEL_STRUCT_PADDING_LOWER);
 const std::string kOptionForceCommandSerialization                   = std::string(kSettingsFilter) + std::string(FORCE_COMMAND_SERIALIZATION_LOWER);
 const std::string kOptionQueueZeroOnly                               = std::string(kSettingsFilter) + std::string(QUEUE_ZERO_ONLY_LOWER);
+const std::string kOptionAllowPipelineCompileRequired                = std::string(kSettingsFilter) + std::string(ALLOW_PIPELINE_COMPILE_REQUIRED_LOWER);
 const std::string kOptionKeyAnnotationExperimental                   = std::string(kSettingsFilter) + std::string(RV_ANNOTATION_EXPERIMENTAL_LOWER);
 const std::string kOptionKeyAnnotationRand                           = std::string(kSettingsFilter) + std::string(RV_ANNOTATION_RAND_LOWER);
 const std::string kOptionKeyAnnotationGPUVA                          = std::string(kSettingsFilter) + std::string(RV_ANNOTATION_GPUVA_LOWER);
@@ -326,6 +341,10 @@ void CaptureSettings::LoadRunTimeEnvVarSettings(CaptureSettings* settings)
         std::string value = util::platform::GetEnv(kCaptureAndroidTriggerEnvVar);
         settings->trace_settings_.runtime_capture_trigger =
             ParseAndroidRunTimeTrimState(value, settings->trace_settings_.runtime_capture_trigger);
+        if (settings->trace_settings_.runtime_capture_trigger != RuntimeTriggerState::kNotUsed)
+        {
+            settings->trace_settings_.trim_boundary = TrimBoundary::kFrames;
+        }
     }
 #endif
 }
@@ -384,8 +403,10 @@ void CaptureSettings::LoadOptionsEnvVar(OptionsMap* options)
 
     // Trimming environment variables
     LoadSingleOptionEnvVar(options, kCaptureFramesEnvVar, kOptionKeyCaptureFrames);
+    LoadSingleOptionEnvVar(options, kQuitAfterFramesEnvVar, kOptionKeyQuitAfterCaptureFrames);
     LoadSingleOptionEnvVar(options, kCaptureTriggerEnvVar, kOptionKeyCaptureTrigger);
     LoadSingleOptionEnvVar(options, kCaptureTriggerFramesEnvVar, kOptionKeyCaptureTriggerFrames);
+    LoadSingleOptionEnvVar(options, kCaptureQueueSubmitsEnvVar, kOptionKeyCaptureQueueSubmits);
 
     // Page guard environment variables
     LoadSingleOptionEnvVar(options, kPageGuardCopyOnMapEnvVar, kOptionKeyPageGuardCopyOnMap);
@@ -417,6 +438,7 @@ void CaptureSettings::LoadOptionsEnvVar(OptionsMap* options)
 
     LoadSingleOptionEnvVar(options, kForceCommandSerializationEnvVar, kOptionForceCommandSerialization);
     LoadSingleOptionEnvVar(options, kQueueZeroOnlyEnvVar, kOptionQueueZeroOnly);
+    LoadSingleOptionEnvVar(options, kAllowPipelineCompileRequiredEnvVar, kOptionAllowPipelineCompileRequired);
 
     // Annotated GPUVA mask
     LoadSingleOptionEnvVar(options, kAnnotationExperimentalEnvVar, kOptionKeyAnnotationExperimental);
@@ -467,10 +489,36 @@ void CaptureSettings::ProcessOptions(OptionsMap* options, CaptureSettings* setti
         FindOption(options, kOptionKeyMemoryTrackingMode), settings->trace_settings_.memory_tracking_mode);
 
     // Trimming options:
-    // trim ranges and trim hotkey are exclusive
-    // with trim key will be parsed only
-    // if trim ranges is empty, else it will be ignored
-    ParseTrimRangeString(FindOption(options, kOptionKeyCaptureFrames), &settings->trace_settings_.trim_ranges);
+    // Trim frame ranges, trim queue submit ranges, and trim frame hotkey are mutually exclusive.
+    // Precedence is frame ranges, queue submit ranges, then frame hotkey.
+    std::string trim_frames = FindOption(options, kOptionKeyCaptureFrames);
+    if (!trim_frames.empty())
+    {
+        ParseUintRangeList(trim_frames, &settings->trace_settings_.trim_ranges, "capture frames");
+        if (!settings->trace_settings_.trim_ranges.empty())
+        {
+            settings->trace_settings_.trim_boundary = TrimBoundary::kFrames;
+        }
+    }
+
+    std::string trim_queue_submits = FindOption(options, kOptionKeyCaptureQueueSubmits);
+    if (!trim_queue_submits.empty())
+    {
+        if (settings->trace_settings_.trim_ranges.empty())
+        {
+            ParseUintRangeList(trim_queue_submits, &settings->trace_settings_.trim_ranges, "capture queue submits");
+            if (!settings->trace_settings_.trim_ranges.empty())
+            {
+                settings->trace_settings_.trim_boundary = TrimBoundary::kQueueSubmits;
+            }
+        }
+        else
+        {
+            GFXRECON_LOG_WARNING(
+                "Settings Loader: Ignoring trim queue submit ranges setting as trim frame ranges has been specified.");
+        }
+    }
+
     std::string trim_key_option        = FindOption(options, kOptionKeyCaptureTrigger);
     std::string trim_key_frames_option = FindOption(options, kOptionKeyCaptureTriggerFrames);
     if (!trim_key_option.empty())
@@ -482,13 +530,20 @@ void CaptureSettings::ProcessOptions(OptionsMap* options, CaptureSettings* setti
             {
                 settings->trace_settings_.trim_key_frames = ParseTrimKeyFramesString(trim_key_frames_option);
             }
+            if (!settings->trace_settings_.trim_key.empty())
+            {
+                settings->trace_settings_.trim_boundary = TrimBoundary::kFrames;
+            }
         }
         else
         {
-            GFXRECON_LOG_WARNING("Settings Loader: Ignore trim key setting as trim ranges has been specified.");
+            GFXRECON_LOG_WARNING("Settings Loader: Ignoring trim key setting as trim ranges has been specified.");
         }
     }
 
+    settings->trace_settings_.quit_after_frame_ranges = ParseBoolString(
+        FindOption(options, kOptionKeyQuitAfterCaptureFrames), settings->trace_settings_.quit_after_frame_ranges);
+
     // Page guard environment variables
     settings->trace_settings_.page_guard_copy_on_map = ParseBoolString(
         FindOption(options, kOptionKeyPageGuardCopyOnMap), settings->trace_settings_.page_guard_copy_on_map);
@@ -524,7 +579,9 @@ void CaptureSettings::ProcessOptions(OptionsMap* options, CaptureSettings* setti
     // Screenshot options
     settings->trace_settings_.screenshot_dir =
         FindOption(options, kOptionKeyScreenshotDir, settings->trace_settings_.screenshot_dir);
-    ParseFramesList(FindOption(options, kOptionKeyScreenshotFrames), &settings->trace_settings_.screenshot_ranges);
+    ParseUintRangeList(FindOption(options, kOptionKeyScreenshotFrames),
+                       &settings->trace_settings_.screenshot_ranges,
+                       "screenshot frames");
     settings->trace_settings_.screenshot_format = ParseScreenshotFormatString(
         FindOption(options, kOptionKeyScreenshotFormat), settings->trace_settings_.screenshot_format);
 
@@ -540,9 +597,14 @@ void CaptureSettings::ProcessOptions(OptionsMap* options, CaptureSettings* setti
 
     settings->trace_settings_.force_command_serialization = ParseBoolString(
         FindOption(options, kOptionForceCommandSerialization), settings->trace_settings_.force_command_serialization);
+
     settings->trace_settings_.queue_zero_only =
         ParseBoolString(FindOption(options, kOptionQueueZeroOnly), settings->trace_settings_.queue_zero_only);
 
+    settings->trace_settings_.allow_pipeline_compile_required =
+        ParseBoolString(FindOption(options, kOptionAllowPipelineCompileRequired),
+                        settings->trace_settings_.allow_pipeline_compile_required);
+
     settings->trace_settings_.rv_anotation_info.rv_annotation =
         ParseBoolString(FindOption(options, kOptionKeyAnnotationExperimental),
                         settings->trace_settings_.rv_anotation_info.rv_annotation);
@@ -767,143 +829,19 @@ util::Log::Severity CaptureSettings::ParseLogLevelString(const std::string&  val
     return result;
 }
 
-void CaptureSettings::ParseTrimRangeString(const std::string&                       value_string,
-                                           std::vector<CaptureSettings::TrimRange>* ranges)
-{
-    assert(ranges != nullptr);
-
-    if (!value_string.empty())
-    {
-        std::istringstream value_string_input;
-        value_string_input.str(value_string);
-
-        for (std::string range; std::getline(value_string_input, range, ',');)
-        {
-            if (range.empty() || (std::count(range.begin(), range.end(), '-') > 1))
-            {
-                GFXRECON_LOG_WARNING("Settings Loader: Ignoring invalid capture frame range \"%s\"", range.c_str());
-                continue;
-            }
-
-            util::strings::RemoveWhitespace(range);
-
-            // Split string on '-' delimiter.
-            bool                     invalid = false;
-            std::vector<std::string> values;
-            std::istringstream       range_input;
-            range_input.str(range);
-
-            for (std::string value; std::getline(range_input, value, '-');)
-            {
-                if (value.empty())
-                {
-                    break;
-                }
-
-                // Check that the value string only contains numbers.
-                size_t count = std::count_if(value.begin(), value.end(), ::isdigit);
-                if (count == value.length())
-                {
-                    values.push_back(value);
-                }
-                else
-                {
-                    GFXRECON_LOG_WARNING("Settings Loader: Ignoring invalid capture frame range \"%s\", which contains "
-                                         "non-numeric values",
-                                         range.c_str());
-                    invalid = true;
-                    break;
-                }
-            }
-
-            if (!invalid)
-            {
-                CaptureSettings::TrimRange trim_range;
-
-                if (values.size() == 1)
-                {
-                    if (std::count(range.begin(), range.end(), '-') == 0)
-                    {
-                        trim_range.first = std::stoi(values[0]);
-                        trim_range.total = 1;
-                    }
-                    else
-                    {
-                        GFXRECON_LOG_WARNING("Settings Loader: Ignoring invalid capture frame range \"%s\"",
-                                             range.c_str());
-                        continue;
-                    }
-                }
-                else if (values.size() == 2)
-                {
-                    trim_range.first = std::stoi(values[0]);
-
-                    uint32_t last = std::stoi(values[1]);
-                    if (last >= trim_range.first)
-                    {
-                        trim_range.total = (last - trim_range.first) + 1;
-                    }
-                    else
-                    {
-                        GFXRECON_LOG_WARNING(
-                            "Settings Loader: Ignoring invalid capture frame range \"%s\", where first "
-                            "frame is greater than last frame",
-                            range.c_str());
-                        continue;
-                    }
-                }
-                else
-                {
-                    GFXRECON_LOG_WARNING("Settings Loader: Ignoring invalid capture frame range \"%s\"", range.c_str());
-                    continue;
-                }
-
-                // Check for invalid start frame of 0.
-                if (trim_range.first == 0)
-                {
-                    GFXRECON_LOG_WARNING(
-                        "Settings Loader: Ignoring invalid capture frame range \"%s\", with first frame equal to zero",
-                        range.c_str());
-                    continue;
-                }
-
-                uint32_t next_allowed = 0;
-
-                // Check that start frame is outside the bounds of the previous range.
-                if (!ranges->empty())
-                {
-                    // This produces the number of the frame after the last frame in the range.
-                    next_allowed = ranges->back().first + ranges->back().total;
-                }
-
-                if (trim_range.first >= next_allowed)
-                {
-                    ranges->emplace_back(trim_range);
-                }
-                else
-                {
-                    GFXRECON_LOG_WARNING("Settings Loader: Ignoring invalid capture frame range \"%s\", "
-                                         "where start frame precedes the end of the previous range \"%u-%u\"",
-                                         range.c_str(),
-                                         ranges->back().first,
-                                         (next_allowed - 1));
-                }
-            }
-        }
-    }
-}
-
-void CaptureSettings::ParseFramesList(const std::string& value_string, std::vector<util::FrameRange>* frames)
+void CaptureSettings::ParseUintRangeList(const std::string&            value_string,
+                                         std::vector<util::UintRange>* frames,
+                                         const char*                   option_name)
 {
     GFXRECON_ASSERT(frames != nullptr);
 
     if (!value_string.empty())
     {
-        std::vector<gfxrecon::util::FrameRange> frame_ranges = gfxrecon::util::GetFrameRanges(value_string);
+        std::vector<gfxrecon::util::UintRange> frame_ranges = util::GetUintRanges(value_string.c_str(), option_name);
 
         for (uint32_t i = 0; i < frame_ranges.size(); ++i)
         {
-            util::FrameRange range{};
+            util::UintRange range{};
             range.first = frame_ranges[i].first;
             range.last  = frame_ranges[i].last;
             frames->push_back(range);
