@@ -1,7 +1,7 @@
 /*
 ** Copyright (c) 2018-2021 Valve Corporation
 ** Copyright (c) 2018-2023 LunarG, Inc.
-** Copyright (c) 2019 Advanced Micro Devices, Inc. All rights reserved.
+** Copyright (c) 2019-2023 Advanced Micro Devices, Inc. All rights reserved.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -287,6 +287,12 @@ class VulkanCaptureManager : public CaptureManager
                                                     const VkAllocationCallbacks*                pAllocator,
                                                     VkAccelerationStructureKHR* pAccelerationStructureKHR);
 
+    void
+    OverrideCmdBuildAccelerationStructuresKHR(VkCommandBuffer                                        commandBuffer,
+                                              uint32_t                                               infoCount,
+                                              const VkAccelerationStructureBuildGeometryInfoKHR*     pInfos,
+                                              const VkAccelerationStructureBuildRangeInfoKHR* const* ppBuildRangeInfos);
+
     VkResult OverrideAllocateMemory(VkDevice                     device,
                                     const VkMemoryAllocateInfo*  pAllocateInfo,
                                     const VkAllocationCallbacks* pAllocator,
@@ -304,6 +310,14 @@ class VulkanCaptureManager : public CaptureManager
                                                   const VkAllocationCallbacks*             pAllocator,
                                                   VkPipeline*                              pPipelines);
 
+    VkResult OverrideDeferredOperationJoinKHR(VkDevice device, VkDeferredOperationKHR operation);
+
+    VkResult OverrideGetDeferredOperationResultKHR(VkDevice device, VkDeferredOperationKHR operation);
+
+    void DeferredOperationPostProcess(VkDevice               device,
+                                      VkDeferredOperationKHR deferredOperation,
+                                      bool                   capture_manager_tracking);
+
     void OverrideGetPhysicalDeviceQueueFamilyProperties(VkPhysicalDevice         physicalDevice,
                                                         uint32_t*                pQueueFamilyPropertyCount,
                                                         VkQueueFamilyProperties* pQueueFamilyProperties);
@@ -1303,6 +1317,7 @@ class VulkanCaptureManager : public CaptureManager
     std::set<DeviceMemoryWrapper*>      mapped_memory_; // Track mapped memory for unassisted tracking mode.
     std::unique_ptr<VulkanStateTracker> state_tracker_;
     HardwareBufferMap                   hardware_buffers_;
+    std::mutex                          deferred_operation_mutex;
 };
 
 GFXRECON_END_NAMESPACE(encode)
