@@ -1,5 +1,6 @@
 /*
 ** Copyright (c) 2019 LunarG, Inc.
+** Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -25,6 +26,7 @@
 
 #include "encode/handle_unwrap_memory.h"
 #include "encode/vulkan_handle_wrappers.h"
+#include "vulkan_scoped_destroy_lock.h"
 #include "format/format.h"
 #include "format/format_util.h"
 #include "generated/generated_vulkan_dispatch_table.h"
@@ -51,7 +53,6 @@ static const VkCommandPool    kTempCommandPool =
     UINT64_TO_VK_HANDLE(VkCommandPool, std::numeric_limits<uint64_t>::max() - 2);
 static const format::HandleId kTempCommandPoolId   = std::numeric_limits<format::HandleId>::max() - 2;
 static const format::HandleId kTempCommandBufferId = std::numeric_limits<format::HandleId>::max() - 3;
-
 typedef format::HandleId (*PFN_GetHandleId)();
 
 extern VulkanStateHandleTable state_handle_table_;
@@ -77,7 +78,7 @@ format::HandleId GetWrappedId(const typename Wrapper::HandleType& handle)
 {
     if (handle == VK_NULL_HANDLE)
     {
-        return 0;
+        return format::kNullHandleId;
     }
     auto temp_id = GetTempWrapperId<Wrapper>(handle);
     if (temp_id != 0)
@@ -90,7 +91,7 @@ format::HandleId GetWrappedId(const typename Wrapper::HandleType& handle)
     {
         GFXRECON_LOG_WARNING("GetWrappedId() couldn't find Handle: %" PRIu64 "'s wrapper. It might have been destroyed",
                              handle);
-        return 0;
+        return format::kNullHandleId;
     }
     return wrapper->handle_id;
 }
@@ -170,6 +171,7 @@ void CreateWrappedDispatchHandle(typename ParentWrapper::HandleType parent,
                                  typename Wrapper::HandleType*      handle,
                                  PFN_GetHandleId                    get_id)
 {
+    ScopedDestroyLock shared_scoped_lock(true);
     assert(handle != nullptr);
     if ((*handle) != VK_NULL_HANDLE)
     {
@@ -199,6 +201,7 @@ void CreateWrappedDispatchHandle(typename ParentWrapper::HandleType parent,
 template <typename Wrapper>
 void CreateWrappedNonDispatchHandle(typename Wrapper::HandleType* handle, PFN_GetHandleId get_id)
 {
+    ScopedDestroyLock shared_scoped_lock(false);
     assert(handle != nullptr);
     if ((*handle) != VK_NULL_HANDLE)
     {
