@@ -65,7 +65,13 @@ const size_t   kAdapterDescriptionSize    = 128;
 
 /// Label for operation annotation, which captures parameters used by tools
 /// operating on a capture file.
-const char* const kAnnotationLabelOperation = "operation";
+const char* const kAnnotationLabelOperation     = "operation";
+const char* const kAnnotationLabelReplayOptions = "replayopts";
+
+const char* const kOperationAnnotationGfxreconstructVersion = "gfxrecon-version";
+const char* const kOperationAnnotationVulkanVersion         = "vulkan-version";
+const char* const kOperationAnnotationTimestamp             = "timestamp";
+const char* const kOperationAnnotationCaptureParameters     = "capture-parameters";
 
 constexpr uint32_t MakeCompressedBlockType(uint32_t block_type)
 {
@@ -138,6 +144,7 @@ enum class MetaDataType : uint16_t
     kCreateHardwareBufferCommand            = 24,
     kReserved25                             = 25,
     kDx12RuntimeInfoCommand                 = 26,
+    kParentToChildDependency                = 27,
 };
 
 // MetaDataId is stored in the capture file and its type must be uint32_t to avoid breaking capture file compatibility.
@@ -339,9 +346,9 @@ struct DriverInfoBlock
 
 struct ExeFileInfoBlock
 {
-    MetaDataHeader              meta_header;
-    format::ThreadId            thread_id;
-    util::filepath::FileInfo    info_record;
+    MetaDataHeader           meta_header;
+    format::ThreadId         thread_id;
+    util::filepath::FileInfo info_record;
 };
 
 // Not a header because this command does not include a variable length data payload.
@@ -618,6 +625,21 @@ struct Dx12RuntimeInfoCommandHeader
     Dx12RuntimeInfo  runtime_info;
 };
 
+enum ParentToChildDependencyType : uint32_t
+{
+    kUnknownDependency                = 0,
+    kAccelerationStructuresDependency = 1
+};
+
+struct ParentToChildDependencyHeader
+{
+    MetaDataHeader              meta_header;
+    format::ThreadId            thread_id;
+    ParentToChildDependencyType dependency_type;
+    format::HandleId            parent_id;
+    uint32_t                    child_count;
+};
+
 // Restore size_t to normal behavior.
 #undef size_t
 
