@@ -1,6 +1,6 @@
 /*
-** Copyright (c) 2018-2020 Valve Corporation
-** Copyright (c) 2018-2020 LunarG, Inc.
+** Copyright (c) 2018-2023 Valve Corporation
+** Copyright (c) 2018-2023 LunarG, Inc.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,7 @@
 #define GFXRECON_PLATFORM_TYPES_H
 
 #include "util/logging.h"
+#include "VK_ANDROID_frame_boundary.h"
 
 #include "vulkan/vulkan.h"
 
@@ -178,6 +179,29 @@ struct VkAndroidHardwareBufferFormatProperties2ANDROID
     VkChromaLocation              suggestedYChromaOffset;
 };
 
+typedef struct VkPhysicalDeviceExternalFormatResolveFeaturesANDROID
+{
+    VkStructureType sType;
+    void*           pNext;
+    VkBool32        externalFormatResolve;
+} VkPhysicalDeviceExternalFormatResolveFeaturesANDROID;
+
+typedef struct VkPhysicalDeviceExternalFormatResolvePropertiesANDROID
+{
+    VkStructureType  sType;
+    void*            pNext;
+    VkBool32         nullColorAttachmentWithExternalFormatResolve;
+    VkChromaLocation externalFormatResolveChromaOffsetX;
+    VkChromaLocation externalFormatResolveChromaOffsetY;
+} VkPhysicalDeviceExternalFormatResolvePropertiesANDROID;
+
+typedef struct VkAndroidHardwareBufferFormatResolvePropertiesANDROID
+{
+    VkStructureType sType;
+    void*           pNext;
+    VkFormat        colorAttachmentFormat;
+} VkAndroidHardwareBufferFormatResolvePropertiesANDROID;
+
 extern "C"
 {
     typedef VkResult(VKAPI_PTR* PFN_vkCreateAndroidSurfaceKHR)(VkInstance                           instance,
