@@ -84,6 +84,12 @@ void android_main(struct android_app* app)
 
     if (run)
     {
+        // Reinitialize logging with values retrieved from command line arguments
+        gfxrecon::util::Log::Settings log_settings;
+        GetLogSettings(arg_parser, log_settings);
+        gfxrecon::util::Log::Release();
+        gfxrecon::util::Log::Init(log_settings);
+
         std::string filename = kDefaultCaptureFile;
 
         if (arg_parser.GetPositionalArgumentsCount() == 1)
@@ -112,13 +118,20 @@ void android_main(struct android_app* app)
                 gfxrecon::decode::VulkanReplayConsumer replay_consumer(application, replay_options);
                 gfxrecon::decode::VulkanDecoder        decoder;
                 uint32_t                               start_frame, end_frame;
-                bool has_mfr = GetMeasurementFrameRange(arg_parser, start_frame, end_frame);
+                bool        has_mfr = GetMeasurementFrameRange(arg_parser, start_frame, end_frame);
+                std::string measurement_file_name;
+
+                if (has_mfr)
+                {
+                    GetMeasurementFilename(arg_parser, measurement_file_name);
+                }
 
                 gfxrecon::graphics::FpsInfo fps_info(static_cast<uint64_t>(start_frame),
                                                      static_cast<uint64_t>(end_frame),
                                                      has_mfr,
                                                      replay_options.quit_after_measurement_frame_range,
-                                                     replay_options.flush_measurement_frame_range);
+                                                     replay_options.flush_measurement_frame_range,
+                                                     measurement_file_name);
 
                 replay_consumer.SetFatalErrorHandler([](const char* message) { throw std::runtime_error(message); });
                 replay_consumer.SetFpsInfo(&fps_info);
